#ifndef XEXCEL_H
#define XEXCEL_H

#include <QObject>

class QAxObject;
class XExcel : public QObject
{
    Q_OBJECT
public:
    explicit XExcel(QObject *parent = nullptr);
    //打开excel com
    void openExcelCom();
    //关闭excel com
    void closeExcelCom();

    QList<QList<QVariant> >  readExcel(QString fileName);
    void readExcels(QList<QString> fileNames);

signals:

private:
    QAxObject* m_pExcel;
    QAxObject* m_pWorkbooks;
};

#endif // XEXCEL_H
